[glib: 4/6] Rename the master branch to main
- From: Philip Withnall <pwithnall src gnome org>
- To: commits-list gnome org
- Cc:
- Subject: [glib: 4/6] Rename the master branch to main
- Date: Mon, 7 Jun 2021 13:22:35 +0000 (UTC)
commit 24e459e3d8c1a402b0a98fa0cbbe1cf432fffa6a
Author: Philip Withnall <pwithnall endlessos org>
Date: Mon Jun 7 13:18:19 2021 +0100
Rename the master branch to main
It’s a more inclusive name, has the same tab-completion prefix, and is
the default choice for new repositories created locally by git, and on
GitHub and GitLab.
https://sfconservancy.org/news/2020/jun/23/gitbranchname/
Signed-off-by: Philip Withnall <pwithnall endlessos org>
Fixes: #2348
.gitlab-ci.yml | 2 +-
.gitlab-ci/meson-junit-report.py | 2 +-
.gitlab-ci/search-common-ancestor.sh | 8 ++++----
CONTRIBUTING.md | 2 +-
4 files changed, 7 insertions(+), 7 deletions(-)
---
diff --git a/.gitlab-ci.yml b/.gitlab-ci.yml
index 16b2c74e8..3c8e7c834 100644
--- a/.gitlab-ci.yml
+++ b/.gitlab-ci.yml
@@ -513,7 +513,7 @@ coverity:
pages:
stage: deploy
only:
- - master
+ - main
needs: ['coverage', 'style-check-diff']
script:
- mv _coverage/ public/
diff --git a/.gitlab-ci/meson-junit-report.py b/.gitlab-ci/meson-junit-report.py
index 1855b4907..1d57ead50 100755
--- a/.gitlab-ci/meson-junit-report.py
+++ b/.gitlab-ci/meson-junit-report.py
@@ -27,7 +27,7 @@ aparser.add_argument(
"--branch",
metavar="NAME",
help="Branch of the project being tested",
- default="master",
+ default="main",
)
aparser.add_argument(
"--output",
diff --git a/CONTRIBUTING.md b/CONTRIBUTING.md
index 52f17b1d9..ba8039d4c 100644
--- a/CONTRIBUTING.md
+++ b/CONTRIBUTING.md
@@ -256,7 +256,7 @@ to avoid unnecessary breakage, and to take advantage of the knowledge about GLib
that has been built up over the years, we’d like to ask people contributing to
GLib to follow a few rules:
-0. Never push to the `master` branch, or any stable branches, directly; you
+0. Never push to the `main` branch, or any stable branches, directly; you
should always go through a merge request, to ensure that the code is
tested on the CI infrastructure at the very least. A merge request is
also the proper place to get a comprehensive code review from the core
[
Date Prev][
Date Next] [
Thread Prev][
Thread Next]
[
Thread Index]
[
Date Index]
[
Author Index]
diff --git a/.gitlab-ci/search-common-ancestor.sh b/.gitlab-ci/search-common-ancestor.sh
index a7a3ac44c..96f45fe69 100755
--- a/.gitlab-ci/search-common-ancestor.sh
+++ b/.gitlab-ci/search-common-ancestor.sh
@@ -9,7 +9,7 @@ ancestor_horizon=28 # days (4 weeks)
# branches.
#
# Limit the fetch to a certain date horizon to limit the amount of data we get.
# If the branch was forked from origin/master before this horizon, it should
# probably be rebased.
if ! git ls-remote --exit-code upstream >/dev/null 2>&1 ; then
git remote add upstream https://gitlab.gnome.org/GNOME/glib.git
@@ -18,7 +18,7 @@ git fetch --shallow-since="$(date --date="${ancestor_horizon} days ago" +%Y-%m-%
# Work out the newest common ancestor between the detached HEAD that this CI job
# has checked out, and the upstream target branch (which will typically be
-# `upstream/master` or `upstream/glib-2-62`).
+# `upstream/main` or `upstream/glib-2-62`).
# `${CI_MERGE_REQUEST_TARGET_BRANCH_NAME}` or `${CI_MERGE_REQUEST_SOURCE_BRANCH_NAME}`
# are only defined if we’re running in a merge request pipeline,
# fall back to `${CI_DEFAULT_BRANCH}` or `${CI_COMMIT_BRANCH}` respectively
@@ -29,8 +29,8 @@ git fetch --shallow-since="$(date --date="${ancestor_horizon} days ago" +%Y-%m-%
newest_common_ancestor_sha=$(diff --old-line-format='' --new-line-format='' <(git rev-list --first-parent
"upstream/${CI_MERGE_REQUEST_TARGET_BRANCH_NAME:-${CI_DEFAULT_BRANCH}}") <(git rev-list --first-parent
"origin/${source_branch}") | head -1)
if [ -z "${newest_common_ancestor_sha}" ]; then
- echo "Couldn’t find common ancestor with upstream master. This typically"
- echo "happens if you branched from master a long time ago. Please update"
+ echo "Couldn’t find common ancestor with upstream main branch. This typically"
+ echo "happens if you branched from main a long time ago. Please update"
echo "your clone, rebase, and re-push your branch."
exit 1
fi
@@ -9,7 +9,7 @@ ancestor_horizon=28 # days (4 weeks)
#
# Limit the fetch to a certain date horizon to limit the amount of data we get.
-# If the branch was forked from origin/master before this horizon, it should
+# If the branch was forked from origin/main before this horizon, it should
# probably be rebased.
if ! git ls-remote --exit-code upstream >/dev/null 2>&1 ; then